aboutsummaryrefslogtreecommitdiffstats
path: root/plugins/mate/mate.h
diff options
context:
space:
mode:
authorLuis Ontanon <luis.ontanon@gmail.com>2005-02-18 22:33:16 +0000
committerLuis Ontanon <luis.ontanon@gmail.com>2005-02-18 22:33:16 +0000
commit2cd67ce4684178099b4692cb698690a06e5f9b56 (patch)
tree013a461207a4a321e8f8bdaf019dfddf44003acc /plugins/mate/mate.h
parent99507223d9a0c9a664d5de9ef45ca515e124dc00 (diff)
Adds Payload AVP to PduDef AVPLs simmetric to the Transport AVP
allows to fetch fields also from ranges that are the payload of the Proto svn path=/trunk/; revision=13427
Diffstat (limited to 'plugins/mate/mate.h')
-rw-r--r--plugins/mate/mate.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/plugins/mate/mate.h b/plugins/mate/mate.h
index 8540e15145..3da59f0594 100644
--- a/plugins/mate/mate.h
+++ b/plugins/mate/mate.h
@@ -100,6 +100,7 @@
#define KEYWORD_PROTO "Proto"
#define KEYWORD_METHOD "Method"
#define KEYWORD_TRANSPORT "Transport"
+#define KEYWORD_PAYLOAD "Payload"
#define KEYWORD_STRICT "Strict"
#define KEYWORD_LOOSE "Loose"
#define KEYWORD_EVERY "Every"
@@ -128,7 +129,7 @@
#define KEYWORD_DEBUGFILENAME "Debug_File"
#define KEYWORD_DBG_GENERAL "Debug_General"
#define KEYWORD_DBG_CFG "Debug_Cfg"
-#define KEYWORD_DBG_PDU "Debug_PDU"
+#define KEYWORD_DBG_PDU "Debug_Pdu"
#define KEYWORD_DBG_GOP "Debug_Gop"
#define KEYWORD_DBG_GOG "Debug_Gog"
#ifdef _AVP_DEBUGGING
@@ -175,7 +176,8 @@ typedef struct _mate_cfg_item {
gboolean discard_pdu_attributes;
gboolean last_to_be_created;
int hfid_proto;
- GPtrArray* hfid_ranges; /* hfids of candidate ranges from which to extract attributes */
+ GPtrArray* transport_ranges; /* hfids of candidate transport ranges from which to extract attributes */
+ GPtrArray* payload_ranges; /* hfids of candidate payload ranges from which to extract attributes */
GHashTable* hfids_attr; /* k=hfid v=avp_name */
gboolean drop_pdu;
avpl_match_mode criterium_match_mode;